# punchbowl

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.14029123.svg)](https://doi.org/10.5281/zenodo.14029123)

`punchbowl` is the science calibration code for [the PUNCH mission](https://punch.space.swri.edu/).

> [!CAUTION]
> This package will likely have breaking changes during commissioning (the first few months after launch).
> Stability is not promised until v1.

## Accessing the data

Data will be available via the Solar Data Analysis Center. More details will be provided after launch.

## Installing `punchbowl`

Install with `pip install punchbowl` to get the released version.

To get the current latest version: clone the repo and install locally.

## Running `punchbowl`

[The documentation](https://punchbowl.readthedocs.io/en/latest/index.html) provides details on how to run the various components.
It also provides a short explanation of each underlying algorithm.
If you want to process larger quantities of data, we suggest using [punchpipe](https://github.com/punch-mission/punchpipe).
Please reach out with a discussion for more help.

## Getting help

Please open an issue or discussion on this repo.

## Contributing

We encourage all contributions.
If you have a problem with the code or would like to see a new feature, please open an issue.
Or you can submit a pull request.
